@@ -6,7 +6,7 @@ App::tt - Time tracking application
 
 =head1 VERSION
 
-0.02
+0.03
 
 =head1 DESCRIPTION
 
@@ -88,7 +88,7 @@ This command is used to import data from other sources. "project-name" default t
 "-p" or current git project, "some description" default to "-d" and tags can be
 specified by -t foo -t bar
 
-  $ tt register 2016-06-28T09:00:00 2016-06-28T17:00:00 "project-name" "some description" "foo,bar"
+  $ tt register 2016-06-28T09:00:00 17:00:00 "project-name" "some description" "foo,bar"
   $ echo "2016-06-28T09:00:00\t2016-06-28T17:00:00\tproject-name\tsome description\tfoo,bar" | tt register
 
 =head2 start
@@ -126,7 +126,7 @@ This command will stop tracking the current event.
 use strict;
 use warnings;
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 =head1 COPYRIGHT AND LICENSE
 
